@@ -11,14 +11,14 @@ __PACKAGE__->config(
       name => 'db1',
       connect_info => {
         driver   => 'SQLite',
-        database => 'testdb1',
+        database => $ENV{CM_JDBI_MEMORY} ? ':memory:' : 'testdb1',
       },
     },
     {
       name => 'db2',
       connect_info => {
         driver   => 'SQLite',
-        database => 'testdb2',
+        database => $ENV{CM_JDBI_MEMORY} ? ':memory:' : 'testdb2',
       },
     },
   ],
